{

  package    #hide
    My;      #our schema
  use 5.010;
  use strict;
  use warnings;
  use utf8;
  use base qw(DBIx::Simple::Class);
  sub namespace {__PACKAGE__}
}
1;
